// HyperMD, copyright (c) by laobubu
// Distributed under an MIT license: http://laobubu.net/HyperMD/LICENSE
//
// POWERPACK for "addon/fold-code"
//
// This module provides `FlowchartRenderer` for FoldCode addon
// so that you can render flowchart with [flowchart.js](http://flowchart.js.org/)
//
// By default the renderer is enabled. You may disable it by setting `hmdFoldCode.flowchart` to `false`
//
// **Example**: https://laobubu.net/HyperMD/docs/examples/flowchart.html
//
// :hint: to change flowchart.js configuration, use `editor.setOption("flowchart", { /* YOUR_CONFiG */ })`
//
// :warning: **flowchart.js bug**
//
// If you are using RequireJS, add `"Raphael": "raphael"` to its `paths` option like this:
//
// ```js
// requirejs.config({
//   // ...
//   paths: {
//     "Raphael": "raphael", // adapt flowchart.js bug
//   },
//   //...
// })
// ```
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};

(function (mod){ //[HyperMD] UMD patched!
  /*commonjs*/  ("object"==typeof exports&&"undefined"!=typeof module) ? mod(null, exports, require("codemirror"), require("flowchart.js"), require("../addon/fold"), require("../addon/fold-code")) :
  /*amd*/       ("function"==typeof define&&define.amd) ? define(["require","exports","codemirror","flowchart.js","../addon/fold","../addon/fold-code"], mod) :
  /*plain env*/ mod(null, (this.HyperMD_PowerPack = this.HyperMD_PowerPack || {}, this.HyperMD_PowerPack["fold-code-with-flowchart"] = {}), CodeMirror, flowchart, HyperMD.Fold, HyperMD.FoldCode);
})(function (require, exports, CodeMirror, flowchart, fold_1, fold_code_1) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.FlowchartRenderer = void 0;
    CodeMirror = __importStar(CodeMirror);
    flowchart = __importStar(flowchart);
    var FlowchartRenderer = function (code, info) {
        var fc = flowchart.parse(code);
        if (Object.keys(fc.symbols).length === 0)
            return null;
        var el = document.createElement("div");
        el.setAttribute("class", "hmd-fold-code-image hmd-fold-code-flowchart");
        // tell Raphael the viewport width
        var tmpContainer = document.createElement("div");
        tmpContainer.setAttribute("style", "position: absolute;left:0;top:0;width:" +
            info.editor.getScrollInfo().clientWidth +
            "px;height:1px;overflow:hidden");
        document.body.appendChild(tmpContainer);
        tmpContainer.appendChild(el);
        fc.drawSVG(el, info.editor.getOption("flowchart"));
        setTimeout(function () {
            document.body.removeChild(tmpContainer);
        }, 100);
        info.onRemove = function () {
            fc.clean();
            fc = null;
        };
        return {
            element: el,
            asyncRenderer: null,
        };
    };
    exports.FlowchartRenderer = FlowchartRenderer;
    if (typeof flowchart === "object") {
        CodeMirror.defineOption("flowchart", null, function (cm) {
            fold_code_1.getAddon(cm).clear("flowchart");
            fold_1.getAddon(cm).startFold();
        });
        fold_code_1.registerRenderer({
            name: "flowchart",
            pattern: /^flow(?:charts?)?$/i,
            renderer: exports.FlowchartRenderer,
            suggested: true,
        });
    }
    else {
        if (window["ECHOMD_DEBUG"]) {
            console.error("[HyperMD] PowerPack fold-code-with-flowchart loaded, but flowchart not found.");
        }
    }
});
